@@ -1,6 +1,6 @@
 import json
-
-from pymacaroons.utils import convert_to_string, convert_to_bytes
+from base64 import standard_b64decode
+from pymacaroons.utils import convert_to_string
 
 
 class JsonSerializer(object):
@@ -15,23 +15,25 @@ class JsonSerializer(object):
         return json.dumps(serialized)
 
     def deserialize(self, serialized):
-        from pymacaroons.raw_macaroon import RawMacaroon
         from pymacaroons.macaroon import Macaroon
         from pymacaroons.caveat import Caveat
 
-        raw_macaroon = RawMacaroon()
-
+        caveats = []
         deserialized = json.loads(convert_to_string(serialized))
-        raw_macaroon._location = deserialized['location']
-        raw_macaroon._identifier = deserialized['identifier']
+
         for c in deserialized['caveats']:
             caveat = Caveat(
-                caveatId=c['cid'],
-                verificationKeyId=c['vid'],
+                caveat_id=c['cid'],
+                verification_key_id=(
+                    standard_b64decode(c['vid']) if c['vid'] else None
+                ),
                 location=c['cl']
             )
-            raw_macaroon._caveats.append(caveat)
-        raw_macaroon._signature = convert_to_bytes(deserialized['signature'])
-        m = Macaroon(location=b'\0', identifier=b'\0', key=b'\0')
-        m._raw_macaroon = raw_macaroon
-        return m
+            caveats.append(caveat)
+
+        return Macaroon(
+            location=deserialized['location'],
+            identifier=deserialized['identifier'],
+            caveats=caveats,
+            signature=deserialized['signature']
+        )
